Rserve: Server providing R functionality to applications via TCP/IP or local unix sockets
Description
Starts Rserve in daemon mode (unix only). Any additional parameters
not related to Rserve will be passed straight to the underlying R. For
configuration, usage and command line parameters please consult the
online documentation at http://www.rforge.net/Rserve.
Use R CMD Rserve --help for a brief help.The Rserve function is provided for convenience only, it is
recommended to start Rserve directly from the command line, not from R
itself. Also note that the debug version of Rserve doesn't fork and thus
will block until closed.
On Windows the Rserve() function sets up the PATH to include the
current R.DLL so that Rserve can be run.
Usage
# R CMD Rserve []Rserve(debug = FALSE, port = 6311, args = NULL, quote=(length(args) > 1), wait, ...)
Arguments
debug
determines whether regular Rserve or debug version of
Rserve (Rserve.dbg) should be started.
port
port used by Rserve to listen for connections
args
further arguments passed to Rserve (as a string that will be
passed to the system command - see quote below).
quote
logical, if TRUE then arguments are quoted,
otherwise they are just joined with spaces
wait
wait argument for the system call. It defaults
to FALSE on Windows and TRUE elsewhere. ...
other arguments to be passes to system. synopsis
Rserve(debug = FALSE, port = 6311, args = NULL, quote=(length(args) > 1), wait, ...)Details
Rserve is not just a package, but an application. It is provided as a
R package for convenience only. For details see
http://www.rforge.net/Rserve