run.Rserve makes the current R process into an Rserve
instance. Rserve takes over until it is shut down or receives a user
interrupt signal. The main difference between Rserve and
run.Rserve is that Rserve starts a new process, whereas
run.Rserve turns the current R session into Rserve. This is only
possible if there are no UI elements or other parts that could
interfere with the prepation of Rserve.run.Rserve(..., config.file = "/etc/Rserve.conf")foo="bar"
has the same meaning as foo bar in the configuration
file. The only exception is that logicalTRUE after the Rserve was shut down.Rserve